#
# spec file for package python-ovsdbapp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define with_tests 1
Name:           python-ovsdbapp
Version:        2.8.0
Release:        1.1
Summary:        A library for creating OVSDB applications
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/ovsdbapp
Source0:        https://files.pythonhosted.org/packages/source/o/ovsdbapp/ovsdbapp-2.8.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-fixtures >= 3.0.0
BuildRequires:  python3-netaddr >= 0.10.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-ovs >= 2.10.0
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-stestr
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
The ovdsbapp library is useful for creating applications that communicate via
Open_vSwitchs OVSDB protocol (https://tools.ietf.org/html/rfc7047). It wraps
the Python 'ovs' and adds an event loop and friendly transactions.

%package -n python3-ovsdbapp
Summary:        A library for creating OVSDB applications
Requires:       python3-fixtures >= 3.0.0
Requires:       python3-netaddr >= 0.10.0
Requires:       python3-ovs >= 2.10.0
Requires:       python3-pbr >= 2.0.0
Requires:       python3-six

%description -n python3-ovsdbapp
The ovdsbapp library is useful for creating applications that communicate via
Open_vSwitchs OVSDB protocol (https://tools.ietf.org/html/rfc7047). It wraps
the Python 'ovs' and adds an event loop and friendly transactions.

%package -n python-ovsdbapp-doc
Summary:        Documentation for OpenStack log library
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-ovsdbapp-doc
Documentation for the ovsdbap library.

%prep
%autosetup -p1 -n ovsdbapp-%{version}
%py_req_cleanup

%build
%{py3_build}

# generate html docs
PBR_VERSION=2.8.0 PYTHONPATH=. \
    %sphinx_build -b html doc/source doc/build/html
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%if 0%{?with_tests}
%check
OS_TEST_PATH=./ovsdbapp/tests/unit PYTHONPATH=. %{openstack_stestr_run}
%endif

%files -n python3-ovsdbapp
%license LICENSE
%doc ChangeLog README.rst
%{python3_sitelib}/ovsdbapp
%{python3_sitelib}/*.egg-info

%files -n python-ovsdbapp-doc
%license LICENSE
%doc doc/build/html

%changelog
* Tue Sep  3 2024 cloud-devel@suse.de
- removed 0001-Improve-compatibility-with-netaddr-1.x.patch
- update to version 2.8.0
  - Use log.warning() from the logging library
  - Improve compatibility with netaddr 1.x
* Tue Jun  4 2024 cloud-devel@suse.de
- update to version 2.7.1
  - reno: Update master for unmaintained/xena
  - reno: Update master for unmaintained/zed
  - ovn-sb: remove chassis from Chassis_Private on ChassisDelCommand
  - reno: Update master for unmaintained/wallaby
  - Handle IPv6 addresses for LB IP port mappings
  - Add pre-commit configuration
  - Remove executable from python files which don't really needs it
  - Add if_exists to lrp_set_options
  - nb: commands: fix passing string to LSP attach/detach mirror API
  - Backend: always operate on (class level) ovsdb_connection
  - reno: Update master for unmaintained/victoria
  - Fix BFD functional test, avoid comparing status column
  - Update master for stable/2024.1
* Fri May 10 2024 cloud-devel@suse.de
- added 0001-Improve-compatibility-with-netaddr-1.x.patch
- update to version 2.6.0
  - tox: Drop envdir
  - Bump hacking
  - reno: Update master for unmaintained/yoga
  - add Port_Binding to lookup_table
  - Update supported python versions
  - Support add/remove CIDR type address in Address_Set cmds
* Thu Jan  4 2024 cloud-devel@suse.de
- update to version 2.5.0
  - Update master for stable/2023.2
  - TAAS: Add commands for creating Mirrors
  - Add support for ecmp routes
  - Ensure LrpAddCommand may_exits works without peers
  - Add some basic usage documentation
  - Handle events with conditions and match_fn
  - nb: provide 'route_table' in lr-route-{add,del,list}
  - nb: allow to add route even if learned route exists
  - venv: unit tests don't work for 'hardware_vtep'
  - nb: add 'nexthop' argument to 'lr_route_del'
* Thu Jun 15 2023 cloud-devel@suse.de
- update to version 2.3.0
  - [CI] Set the default OS_TEST_PATH in the stestr conf file
  - Use OVN's OVS submodule for functional tests
  - Add Interface paramteres to ``OvsdbIdl.add_port`` method.
  - All ``AddCommand`` child classes return the new register UUID
  - Update master for stable/2023.1
  - Add support for manipulating BFD entries
  - Add new function ls_get_localnet_ports
  - Add 'no timeout' option to wait_for_change
  - Add if_exists and **kwargs columns to db_set
* Mon Mar  6 2023 cloud-devel@suse.de
- update to version 2.2.1
  - Update tox.ini for tox4
  - Accept HA chassis group commands in HAChassisGroupAdd*
  - Define "LbAddIpPortMappingCommand" with latin chars
* Thu Dec  1 2022 cloud-devel@suse.de
- update to version 2.2.0
  - Don't force_reconnect() on unhandled Idl exception
  - Fix TRY_AGAIN handling
  - Switch to 2023.1 Python3 unit tests and generic template name
  - Use daemon property instead of setDaemon method
  - vtep: add support for 'hardware_vtep' schema
  - nb: add methods to modify the lrp.networks
  - nb: add support for lb health checks API
  - Provide base classes for {Get,Set}Options commands
  - Update master for stable/zed
  - Fix logging exception while handling transaction exception
* Sat Oct  1 2022 cloud-devel@suse.de
- update to version 2.0.0
  - Update python testing as per zed cycle teting runtime
* Tue Jun  7 2022 cloud-devel@suse.de
- update to version 1.16.1
  - Handle OVS 2.17 change to Idl.tables
  - nb: set chassis_name for new gateway chassis
  - tools: fix OvsOvnVenvFixture init
  - Log what exception caused abort of the transaction
  - nb: provide 'discard' value for nexthop
  - Update master for stable/xena
  - ic: add support for OVN_IC_Northbound schema
  - Add cooperative_yield() to OvsdbIdl
  - Capture test run logging
  - Update master for stable/yoga
  - Remove ovsdb_connection singleton for tests
  - nb: provide lrp_get method
  - Check WaitEvents for match after other events
  - Use "api.lookup" to search for a "Logical_Switch"
  - github no longer accepts git:// connections
  - Allow functional tests to pass on older OVN w/o IC
  - nb: fix route.output_port name
  - Use py3 as the default runtime for tox
  - Drop lower-constraints.txt and its testing
  - tools: run functional tests against ovn/main branch
  - Add Python3 yoga unit tests
  - Add support for OVN NB Logical_Router_Policy table
  - Move linters dependencies to tox.ini
  - remove unicode from code
  - nb: add support for lrp's gateway chassis API
  - Fix broken behavior after recent OVS update
  - Update QoS register in "QoSAddCommand" if exists
  - nb: add support for set of addresses API
  - Revert "Add an active wait in the "Backend.lookup""
* Mon Dec  6 2021 cloud-devel@suse.de
- update to version 1.12.0
  - Improve "OvsdbIdl.from_server" method
  - Don't spam retries 100s of times a second
  - Actually close the connection in Connection.stop()
  - Fix docs job
  - ovn: support allow-stateless ACL verb
  - Make exceptions in the event logs easier to read
  - Add Python3 xena unit tests
  - Update master for stable/wallaby
  - Add an active wait in the "Backend.lookup"
  - setup.cfg: Replace dashes with underscores
* Sun May  2 2021 cloud-devel@suse.de
- update to version 1.9.0
  - Switch from unittest2 compat methods to Python 3.x methods
  - Bump ovs minimum version for support of indexing
  - Add northbound API support for meters
  - Fix gate failure
  - Fix NB API definition "lb_add" method signature
  - Don't use name mangling when we don't need it
  - Avoid race condition with RowEvent handling
  - Don't compile OVS kernel module
  - Add update_tables method to Idl
  - requirements: Drop os-testr
  - Update Python3 wallaby unit tests
  - Drop py37 and add py38 test
  - Make it possible to just retrieve schema json
  - Don't give up when an Exception happens in idl.run
  - Log the name of the command in execute()
  - Stop to use the __future__ module.
  - [ovn nb] Acl add: Avoid setting columns that have no values
  - Update master for stable/victoria
  - Ensure lists of Commands can be stringfied
* Tue Feb  2 2021 cloud-devel@suse.de
- update to version 1.6.0
  - Update TOX_CONSTRAINTS_FILE for stable/victoria
  - Bump ovs minimum version for support of indexing
  - Avoid race condition with RowEvent handling
  - Update .gitreview for stable/victoria
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 1.5.0
  - Import ABCs from 'collections.abc'
  - Add QoSDelExtIdCommand
  - Update master for stable/ussuri
  - Handle index lookups in DbFindCommand
  - Add "inactivity_probe" parameter to "enable_connection_uri"
  - Add a cause description to "TimeoutException"
  - Add "if_exists" parameter to "QoSDelCommand"
  - Stop iterating on first matching QoS rule
  - Remove translation sections from setup.cfg
  - Allow read-only Commands to bypass txns in execute()
  - Only create indices if connection is not running
  - drop mock from lower-constraints
  - Fix thread/threading change in unit test
  - Fix hacking min version to 3.0.1
  - Don't let an Exception in one event affect others
  - Add indexed column support to ovsdbapp
  - Change TestOvnNbIndex.test_find to use Port_Group
  - Remove the dependency on the "mock" package
  - Make it more obvious when errors are ignored
  - Add MAC_Binding index lookup
  - Tempest job inherits from Neutron tempest OVN job
  - Switch to newer openstackdocstheme and reno versions
  - Fix spurious test failure
  - Accept a Row as a result in AddCommand
  - Remove all usage of six library
  - Update hacking for Python3
  - Don't create new API instance in fixtures
  - Fix pep8 job
  - Correct variable names for test
  - Add lock when calling idl.run()
  - OVNNB backend: Fix LbDelCommand when using vip param
* Mon Aug 10 2020 cloud-devel@suse.de
- update to version 1.2.0
  - Allow read-only Commands to bypass txns in execute()
  - Add "inactivity_probe" parameter to "enable_connection_uri"
  - Accept a Row as a result in AddCommand
  - Update .gitreview for stable/ussuri
  - Tempest job inherits from Neutron tempest OVN job
  - Fix spurious test failure
  - Update TOX/UPPER_CONSTRAINTS_FILE for stable/ussuri
* Tue May 12 2020 cloud-devel@suse.de
- update to version 1.1.0
  - Log invalid address values in lsp_set_addresses
  - Make it possible to reference a newly created object within a transaction
  - Help with troubleshooting failures from venv.py
  - Handle unset OVN_SRCDIR
  - Change EAFP to LBYL style in nested transaction
  - Drop python 2 support and testing
  - Update master for stable/train
  - Do not try to execute transaction if command list is empty
  - ovn_northbound: make all list commands ReadOnlyCommand
  - Handle the ovs/ovn split
  - More robustly handle venv ovs/ovn paths
  - PDF documentation build
  - Add consts for OVN install path
  - Fix the url, change http to https
  - Make ovndir configurable
  - Default testenv to basepython = python3
  - Switch to Ussuri jobs
  - Update Zuul jobs: Enable docs publishing
  - Fix debug_venv for ovn split
  - Call row.verify() when updating map columns with db_set
  - Fix building OVS after python2 removal
* Thu Mar 12 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only client
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 0.17.0
  - modify RowEvent hash key
  - Mock Thread for both connection tests
  - Add missing tox environment "functional-py36"
  - TrivialFix: Fix the chassis_del comment in Southbound API
  - Add mock.patch.stopall cleanup handler to base test class
  - Make Event logging more useful by default
  - Make event debug log more useful
  - Switch functional and tempest jobs to python3
  - Allow match_ip in LrNatDelCommand to be IP network
  - Add db_create_row method
  - Break out match_fn from matches
  - Sync Sphinx requirement
  - Remove vtep-related code from venv testing
  - Add Python 3 Train unit tests
  - OpenDev Migration Patch
  - Make it possible to opt out of nested transactions
  - Add HA Chassis Group related commands
  - Add commands to set and get LRP options
  - Pass kwargs from execute to transaction()
  - Replace openstack repository by opendev
  - Bump appdirs lower constraint
  - Update the UPPER_CONSTRAINTS_FILE for tox
  - Update master for stable/stein
  - Move WaitForPortBindingEvent out from testing code
  - add an option to let the user choose the right time to start connection
  - Change the order of parameters for lsp_bind method
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 0.15.0
  - Update home-page
  - Check for oslo library usage
  - Pass posargs to pylint, not flake8
  - Fix functional tests timeout race condition
  - Expand retry behavior to cover other python-ovs methods
  - update pylint to 1.9.2
  - import zuul job settings from project-config
  - NBDB API: Add param if_exists for methods using db_remove()
  - Change openstack-dev to openstack-discuss
  - Add Gateway_Chassis support
  - Update reno for stable/rocky
  - Attempt to fetch the schema from any remote
  - Fix a typo in docstring
  - add python 3.6 unit test job
  - Add WaitEvent to the API
  - Ensure timeout on queueing transaction
  - Remove the oslo-utils dependency
  - Group tests in same class to run in same group
  - Move ovsdbapp jobs to its tree
  - Convert base commands to ReadOnlyCommand
  - fix tox python3 overrides
  - Allow read-only Commands to bypass txns in execute()
  - Migrate tempest job to zuul v3 native
  - ut: Patch get_ident for race transaction test
  - Make nested transaction thread aware
* Wed Mar  6 2019 cloud-devel@suse.de
- update to version 0.12.3
  - Allow read-only Commands to bypass txns in execute()
  - Convert base commands to ReadOnlyCommand
  - Move ovsdbapp jobs to its tree
* Thu Oct 11 2018 cloud-devel@suse.de
- update to version 0.12.2
  - Update UPPER_CONSTRAINTS_FILE for stable/rocky
  - Remove the oslo-utils dependency
  - Check for oslo library usage
  - Update .gitreview for stable/rocky
  - ut: Patch get_ident for race transaction test
  - import zuul job settings from project-config
  - Make nested transaction thread aware
* Tue Sep  4 2018 cloud-devel@suse.de
- update to version 0.12.0
  - Display attempt number during transaction commit
  - Add Port_Group commands
  - TOX/pep8: Enforce the use of python2
  - Add LrGet command
  - Avoid tox_install.sh for constraints support
  - Extend transaction with multiple commands
  - Update reno for stable/queens
  - Change external_ids to columns, in dns_add API
  - Improve DbListCommand operation from O(n^2) to O(n)
  - Support setting of interface external-ids
  - Fix spelling error
  - Switch to stestr
  - Update OvsdbConnectionUnavailable error message
  - Add QoS command for ovn northbound db.
  - Use api.lookup instead of idlutils.row_by_record
  - Make it possible to run functional tests again
  - Add Port Group ACL commands
  - Port Group's letfovers
  - Document *_extenal_ids methods in open_vswitch/api.py
  - IP should be optional in lsp_set_addresses
  - Fix python3 compat with debug_venv.py
  - Transaction: Handle NOT_LOCKED status
  - Ensure idl.run() called on TRY_AGAIN
  - Updated from global requirements
  - add lower-constraints job
* Fri Mar  2 2018 cloud-devel@suse.de
- update to version 0.9.1
  - Add ability to debug OVS virtual environments
  - There is no documentation for ovsdbapp
  - Return False when comparing a RowEvent to something else
  - Don't throw NotConnectedError in queue_txn
  - Add set_column(s) for ovs_idl backend
  - pylint: Disable duplicate-code for check
  - venv: Change --enable-dummy default to override
  - Add RowView versions of db_find and db_list
  - Fix condition_map type checking for strings
  - Removes unnecessary utf-8 encoding
  - rearrange existing documentation to fit the new standard layout
  - Add OVN Northbound API for LS, LSP, and DHCP
  - Add OVN_Northbound API LR, LRP, and LB commands
  - Fix vlog level filtering
  - venv: Split OvsVenvFixture to OVS and OVN
  - The python 3.5 is added
  - Don't wait on TRY_AGAIN when calling commit_block()
  - Update the documentation link for doc migration
  - Add OVN_Southbound API support
  - Add command for deleting row column values
  - Allow to stop and restart connections in Backend
  - Enable warning-is-error in doc build
  - Switch from oslosphinx to openstackdocstheme
  - Have debug_venv use OVN venv
  - Change parent to parent_name in lsp_add
  - Adding {LS|LSP|DHCP_options}_get to OVN Northbound API
  - Remove ignoring _ builtin usage for pep8
  - Add DNS APIs
  - Update UPPER_CONSTRAINTS_FILE for stable/queens
  - Fix BridgeFixture
  - Don't create a sandbox chassis by default
  - Add RowEvent mechanism from networking-ovn
  - Modify LSP List command to return all ports
  - Enable pylint 1.4.5
  - nb_schema: Use normalize_ip_port even for lb ips
  - Allow use of installed OVS if OVS_SRCDIR not set
  - Don't return garbage if table has no index col
  - Add backward compatible connection attribute
  - Update reno for stable/pike
  - Add native IDL tests from neutron
  - Drop MANIFEST.in - it's not needed by pbr
  - Move ovsdb_connection definition to Backend
  - Don't add non-strings to external_ids
  - Update .gitreview for stable/queens
  - Make schema-agnostic db commands part of base API
  - Fix _ls_add-based tests
  - Add Windows support when using eventlet with monkey_patch
  - Ensure idl.run() called on TRY_AGAIN
  - Updated from global requirements
* Tue Feb 13 2018 cloud-devel@suse.de
- update to version 0.4.2
  - Ensure idl.run() called on TRY_AGAIN
* Fri Jan 12 2018 cloud-devel@suse.de
- update to version 0.4.1
  - Update .gitreview for stable/pike
  - Updated from global requirements
  - Don't wait on TRY_AGAIN when calling commit_block()
  - Update UPPER_CONSTRAINTS_FILE for stable/pike
* Fri Aug 25 2017 tbechtold@suse.com
- Initial packaging (version 0.4.0)
